==============
Publishing Boy
==============


.. image:: https://img.shields.io/pypi/v/publishing_boy.svg
        :target: https://pypi.python.org/pypi/publishing_boy

.. image:: https://img.shields.io/travis/przemekkot/publishing_boy.svg
        :target: https://travis-ci.org/przemekkot/publishing_boy

.. image:: https://readthedocs.org/projects/publishing-boy/badge/?version=latest
        :target: https://publishing-boy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/przemekkot/publishing_boy/shield.svg
     :target: https://pyup.io/repos/github/przemekkot/publishing_boy/
     :alt: Updates



Publishing Boy is preparing content for publishing.


* Free software: MIT license
* Documentation: https://publishing-boy.readthedocs.io.





Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
